package com.jiuqi.util;

import java.sql.Time;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/DataConvert.class */
public class DataConvert {
    public static final int ftString = 12;
    public static final int ftInteger = 4;
    public static final int ftBoolean = -7;
    public static final int ftFloat = 2;
    public static final int ftDate = 91;
    public static final int ftDateTime = 93;
    public static final String[] BoolTrueCaptions = {"是", "真", "True", "T", JqLib.SQL_TRUE};
    public static final String[] BoolFalseCaptions = {"否", "假", "False", "F", JqLib.SQL_FALSE};
    public static final SimpleDateFormat default_date_format = new SimpleDateFormat("yyyy-MM-dd");
    public static final SimpleDateFormat default_time_format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    public static int stringToInt(String data) {
        if (data != null) {
            try {
                if (!data.equals("")) {
                    return Integer.parseInt(data);
                }
            } catch (NumberFormatException unused) {
                return 0;
            }
        }
        return 0;
    }

    public static boolean stringToBool(String str) {
        if (str == null) {
            return false;
        }
        for (int i = 0; i < BoolTrueCaptions.length; i++) {
            if (str.equalsIgnoreCase(BoolTrueCaptions[i])) {
                return true;
            }
        }
        return false;
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:7:0x0007. Please report as an issue. */
    public static Object stringToValue(String data, int zbtype) {
        if (data == null) {
            return null;
        }
        try {
            switch (zbtype) {
                case ftBoolean /* -7 */:
                    return stringToBool(data) ? Boolean.TRUE : Boolean.FALSE;
                case 2:
                    if (data.equals("")) {
                        return null;
                    }
                    return Double.valueOf(data);
                case 4:
                    try {
                        if (data.equals("")) {
                            return null;
                        }
                        return Integer.valueOf(data);
                    } catch (NumberFormatException unused) {
                        return new Integer(Double.valueOf(data).intValue());
                    }
                case ftString /* 12 */:
                    return data;
                case ftDate /* 91 */:
                    return default_date_format.parse(data);
                case ftDateTime /* 93 */:
                    return new Timestamp(default_time_format.parse(data).getTime());
                default:
                    return null;
            }
        } catch (NumberFormatException unused2) {
            return null;
        } catch (ParseException unused3) {
            return null;
        }
    }

    public static String valueToString(int value) {
        return String.valueOf(value);
    }

    public static String valueToString(Object value) {
        return valueToString(value, false);
    }

    public static String valueToString(Object value, boolean quoteString) {
        if (value == null) {
            return null;
        }
        if (value instanceof Double) {
            return value.toString();
        }
        if (value instanceof Integer) {
            return value.toString();
        }
        if (value instanceof Boolean) {
            return ((Boolean) value).booleanValue() ? JqLib.SQL_TRUE : JqLib.SQL_FALSE;
        }
        if (value instanceof String) {
            return !quoteString ? (String) value : JqLib.quoteString((String) value);
        }
        if (value instanceof Time) {
            return default_time_format.format((Date) value);
        }
        if (value instanceof Timestamp) {
            return default_time_format.format((Date) value);
        }
        if (value instanceof Date) {
            return default_date_format.format((Date) value);
        }
        if (value instanceof Calendar) {
            return default_date_format.format(((Calendar) value).getTime());
        }
        return value.toString();
    }

    public static String valuesToString(Object value, boolean quoteString) {
        if (value == null) {
            return null;
        }
        if (value instanceof Object[]) {
            Object[] values = (Object[]) value;
            String result = "";
            for (Object obj : values) {
                result = String.valueOf(result) + valueToString(obj, quoteString) + ';';
            }
            return result;
        }
        return valueToString(value, quoteString);
    }
}
